package com.persagy.server.client

import com.persagy.dmp.basic.config.DigitalFeignConfig
import com.persagy.server.Opts
import com.persagy.server.constant.AdmMiddlewareUrlConstant
import com.persagy.server.datacenter.models.entities.objects.Building
import com.persagy.server.datacenter.models.entities.objects.Equipment
import com.persagy.server.datacenter.models.entities.task.BuildingDic
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.responses.SQueryResponse
import org.springframework.cloud.openfeign.FeignClient
import org.springframework.cloud.openfeign.SpringQueryMap
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestHeader

/**
 * @description:数据中台dmp-rwd 物理世界、数据字典、IOT 接口feign
 * @author:lgy
 * @data:2021/8/11 14:56
 */
@FeignClient(name = "adm-middleware", configuration = [DigitalFeignConfig::class])
interface AdmMiddlewareClient{
    /**
     * @description: 查询建筑列表
     * @param: objectUrlParam 对象请求url通用参数
     * @param: criteria post请求参数
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(AdmMiddlewareUrlConstant.BUILDING_QUERY)
    fun queryBuilding(@RequestHeader(defaultValue = "0" ) groupCode: String?, @RequestHeader(defaultValue = "0" ) projectId: String?, @RequestBody criteria: SQueryRequest?): SQueryResponse<Building>?

    /**
     * @description: 查询设备列表
     * @param: objectUrlParam 对象请求url通用参数
     * @param: criteria post请求参数
     * @return: com.persagy.dmp.common.DmpResult
     */
    @PostMapping(AdmMiddlewareUrlConstant.EQUIP_QUERY)
    fun queryEquip(@RequestHeader(defaultValue = "0" ) groupCode: String?, @RequestHeader(defaultValue = "0" ) projectId: String?,@RequestBody criteria: SQueryRequest?): SQueryResponse<Equipment>?


}